slepc-3.18.0 2022-10-01
Report Typos and Errors

# MFNGetBV

Obtain the basis vectors object associated to the matrix function solver.

### Synopsis

    #include "slepcmfn.h"
    PetscErrorCode MFNGetBV(MFN mfn,BV *bv)

Not Collective

### Input Parameters

| mfn | - matrix function context obtained from MFNCreate()

### Output Parameter

| bv | - basis vectors context

### See Also

MFNSetBV()

### Level

advanced

### Location

src/mfn/interface/mfnbasic.c
Index of all MFN routines
Table of Contents for all manual pages
Index of all manual pages